#include <sdet/sdet_contour.h>
#include <sdet/sdet_detector.h>
#include <sdet/sdet_detector_params.h>
#include <sdet/sdet_edge_champher.h>
#include <sdet/sdet_edgel_regions.h>
#include <sdet/sdet_fit_conics.h>
#include <sdet/sdet_fit_conics_params.h>
#include <sdet/sdet_fit_lines.h>
#include <sdet/sdet_fit_lines_params.h>
#include <sdet/sdet_gauss_fit.h>
#include <sdet/sdet_grid_finder.h>
#include <sdet/sdet_grid_finder_params.h>
#include <sdet/sdet_harris_detector.h>
#include <sdet/sdet_harris_detector_params.h>
#include <sdet/sdet_nonmax_suppression.h>
#include <sdet/sdet_nonmax_suppression_params.h>
#include <sdet/sdet_region.h>
#include <sdet/sdet_region_edge.h>
#include <sdet/sdet_region_edge_sptr.h>
#include <sdet/sdet_region_proc.h>
#include <sdet/sdet_region_proc_params.h>
#include <sdet/sdet_region_sptr.h>
#include <sdet/sdet_watershed_region_proc.h>
#include <sdet/sdet_watershed_region_proc_params.h>
#include <sdet/sdet_img_edge.h>

int main() { return 0; }
